__version__ = "0.1"
__git_commiter_name__ = "Tal Yalon"
__git_commiter_email__ = "tal.yalon@gmail.com"
__git_branch__ = '(Not currently on any branch)'
__git_remote_tracking_branch__ = '(No remote tracking)'
__git_remote_url__ = '(Not remote tracking)'
__git_head_hash__ = '68e16f621134bcc2393d2ab8b0fd84297c832e05'
__git_head_subject__ = 'Finished release v0.1.'
__git_head_message__ = ''
__git_dirty_diff__ = ''